Karate notes

home | articles | links | fun | about Up to: Quick math and science observations

Karate notes

# Tue 05/29/01: breaking guard, mount, leg lock, oompa

For maintaining mount, swim arms when they try to push up Front naked choke-push forearm into their neck (either side) and push them away.

When mounted: if their arm behind your head, pin their forearm to ground using back of your head. Then hook leg and oompa. Hip out-try and "crab out" like John did. More of a butt movement, keep legs in same position

Break Guard: Get back. Turn a little sideways, hook your arm under and get their left leg off. Push their leg up to their head, keep your hands in a frame as you turn. Go around, get into side mount.

Also leglock: once you have broken guard, keep their leg in your frame. Lean backwards, roll onto back. Hook their ankle under your armpit and in your arm. Twist your arm, break the ankle.

Break Guard 2 (John's way): You're in guard. Get up, into deep horse stance with their legs on your hips/thighs. Push their legs out with your elbows. Can climb up into mount from there.

Alex's armbar: after they have fallen, you are in horse stance, they are on ground. Step directly over them, pull up on their arm. Reverse armlock (they are on their stomach, you are on one side, pulling up the arm).

Regular armbar: Remember to keep knees tight! Pull their hand to chest, turn their thumb to the sky. Pull their arm down to the pinky side, not straight down on the nuts.

# Thurs 05/31/01: San Chin, some grappling and throws

San Chin: don't rock back then forward. Load up on the leg, bend it slightly, then do thrust completely outward. Leaning back then forward takes too much time.

Throws: 3 steps (don't do them at the same time, just do them smoothly). 1: Step in, pull their hand/elbow to your chest. 2: Forearm strike to chest/neck, knock them off balance. 3: Step past them (hips go past them!) with your closest leg, then reap. Keep their arm tight as they fall, then you can do the armlock.

Steve's Aikido throw: They punch/stab at you w/right hand. Pull them in with your right, step back and to the side. Also put your left hand behind their head and pull them along. As they begin to turn, put your right forearm on their neck and crank them backwards toward the ground (like slamming the basketball on the ground).

Breakfalling: to practice, step forward with right leg. Fall down, slapping right hand. Legs stay on ground as you fall, don't roll back.

# Tuesday June 5

Throw (on John): Be strong: push them with your left arm, pull in their left arm. Do leg sweep, be strong on down part.

Steve's choke: clasp hands together... twist hands. Monkey clap. Effective, good when have back. For rear choke, grab own head, gets a tighter choke.